HbStyle class

Constructors

HbStyle()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

boxR12 BoxDecoration
no setter
boxR12Border BoxDecoration
no setter
boxR16 BoxDecoration
no setter
boxR16Border BoxDecoration
no setter
boxR8 BoxDecoration
no setter
boxR8Border BoxDecoration
no setter
text11 TextStyle
no setter
text11Bold TextStyle
no setter
text11BoldGrey TextStyle
no setter
text11Grey TextStyle
no setter
text11w500 TextStyle
no setter
text11w500Grey TextStyle
no setter
text11w600 TextStyle
no setter
text11w600Grey TextStyle
no setter
text12 TextStyle
no setter
text12Bold TextStyle
no setter
text12BoldGrey TextStyle
no setter
text12Grey TextStyle
no setter
text12w500 TextStyle
no setter
text12w500Grey TextStyle
no setter
text12w600 TextStyle
no setter
text12w600Grey TextStyle
no setter
text13 TextStyle
no setter
text13Bold TextStyle
no setter
text13BoldGrey TextStyle
no setter
text13Grey TextStyle
no setter
text13w500 TextStyle
no setter
text13w500Grey TextStyle
no setter
text13w600 TextStyle
no setter
text13w600Grey TextStyle
no setter
text14 TextStyle
no setter
text14Bold TextStyle
no setter
text14BoldGrey TextStyle
no setter
text14Grey TextStyle
no setter
text14w500 TextStyle
no setter
text14w500Grey TextStyle
no setter
text14w600 TextStyle
no setter
text14w600Grey TextStyle
no setter
text15 TextStyle
no setter
text15Bold TextStyle
no setter
text15BoldGrey TextStyle
no setter
text15Grey TextStyle
no setter
text15w500 TextStyle
no setter
text15w500Grey TextStyle
no setter
text15w600 TextStyle
no setter
text15w600Grey TextStyle
no setter
text16 TextStyle
no setter
text16Bold TextStyle
no setter
text16BoldGrey TextStyle
no setter
text16Grey TextStyle
no setter
text16w500 TextStyle
no setter
text16w500Grey TextStyle
no setter
text16w600 TextStyle
no setter
text16w600Grey TextStyle
no setter
text24 TextStyle
no setter
text24Bold TextStyle
no setter
text24BoldGrey TextStyle
no setter
text24Grey TextStyle
no setter
text24w500 TextStyle
no setter
text24w500Grey TextStyle
no setter
text24w600 TextStyle
no setter
text24w600Grey TextStyle
no setter
text28 TextStyle
no setter
text28Bold TextStyle
no setter
text28BoldGrey TextStyle
no setter
text28Grey TextStyle
no setter
text28w500 TextStyle
no setter
text28w500Grey TextStyle
no setter
text28w600 TextStyle
no setter
text28w600Grey TextStyle
no setter
text32 TextStyle
no setter
text32Bold TextStyle
no setter
text32BoldGrey TextStyle
no setter
text32Grey TextStyle
no setter
text32w500 TextStyle
no setter
text32w500Grey TextStyle
no setter
text32w600 TextStyle
no setter
text32w600Grey TextStyle
no setter

Static Methods

boxImage(ImageProvider<Object> image, {double radius = 0, List<BoxShadow>? boxShadow, Color? color, BoxFit? fit, BorderRadius? borderRadius, Gradient? gradient, Alignment? alignment}) BoxDecoration
toBoxR12({Color? color, List<BoxShadow>? boxShadow, Color? borderColor, Gradient? gradient}) BoxDecoration
toBoxR16({Color? color, Color? borderColor, List<BoxShadow>? boxShadow, Gradient? gradient}) BoxDecoration
toBoxR8({Color? color, List<BoxShadow>? boxShadow, Gradient? gradient, Color? borderColor}) BoxDecoration
toText11({FontWeight? fontWeight, Color? color}) → dynamic
toText12({FontWeight? fontWeight, Color? color}) → dynamic
toText13({FontWeight? fontWeight, Color? color}) → dynamic
toText14({FontWeight? fontWeight, Color? color}) → dynamic
toText15({FontWeight? fontWeight, Color? color}) → dynamic
toText16({FontWeight? fontWeight, Color? color}) → dynamic
toText24({FontWeight? fontWeight, Color? color}) → dynamic
toText28({FontWeight? fontWeight, Color? color}) → dynamic
toText32({FontWeight? fontWeight, Color? color}) → dynamic