hb_common library

Classes

HbAmountFormatter
输入数字限制 digit 最多可以输入的小数位数 max 输入的数字不得超过此值
HbAppBar
Customized navigation bar 自定义导航栏
HbButton
HbCacheFile
HbColor
HbCommonLocalizations
The actual Localizations class is HbCommonLocalizationsImpl, this class exists only for forward compatibility purposes...
HbCommonLocalizationsDelegate
The actual Localizations class is HbCommonLocalizationsImpl,
HbCrypto
HbDialog
HbErrorReport
A utility class for handling and reporting errors in Flutter applications.
HbForm
HbFormController
HbFormData
HbFormWidget<T>
HbIcon
HbInput
HbInputState
HbList<T>
HbNum
Utility class for numerical operations with null safety
HbPageApiCall<T>
HbPageModel<T>
HbRadioController
HbSelect
HbSelectItemModel<T>
HbStorage
HbStyle
HbUtil

Typedefs

BackCallback = void Function()
CancelFunc = void Function()
FnCallBack = void Function()
FormatFn<T> = DateFormat Function([dynamic locale])
HbValidatorFnType = String? Function(String?)?
LoadMoreCallback = Future<void> Function()
RefreshCallback = Future<void> Function()