HbCommonLocalizationsImplZh class
The translations for Chinese (zh).
- Inheritance
-
- Object
- HbCommonLocalizationsImpl
- HbCommonLocalizationsImplZh
Constructors
- HbCommonLocalizationsImplZh([String locale = 'zh'])
Properties
- confirm → String
-
No description provided for @confirm.
no setteroverride
- confirmPasswordError → String
-
No description provided for @confirmPasswordError.
no setteroverride
- copySuccess → String
-
No description provided for @copySuccess.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- loading → String
-
No description provided for @loading.
no setteroverride
- localeName → String
-
finalinherited
- noData → String
-
No description provided for @noData.
no setteroverride
- pleaseSelect → String
-
No description provided for @pleaseSelect.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- send → String
-
No description provided for @send.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
totalTip(
int count) → String -
No description provided for @totalTip.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited