HbAmountFormatter class

输入数字限制 digit 最多可以输入的小数位数 max 输入的数字不得超过此值

Inheritance

Constructors

HbAmountFormatter({int digit = 18, num max = double.infinity, bool allow = true})

Properties

allow bool
Whether the pattern is an allow list or not.
finalinherited
digit int
final
filterPattern Pattern
A Pattern to match or replace in incoming TextEditingValues.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
max num
final
replacementString String
String used to replace banned patterns.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited