HbCacheFile class

Constructors

HbCacheFile()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteAllCacheFiles() Future<void>
删除所有文件
deleteBytesToFile({FileType fileType = FileType.image}) Future<void>
删除特定类型文件
getFile(String url, {FileType fileType = FileType.image, bool returnAllPath = true}) Future<String>
获取图片,并保存图片到本地,并返回图片 returnAllPath: true全部,false:只返回后半部分
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

documentsDirectory Directory?
getter/setter pair

Static Methods

getLocalFilePath(String path) String
拼接本地路径