HbCrypto class

Constructors

HbCrypto()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decryptString(String encryptStr, String private) String
私钥解密
encryptString(String text, String public) String
公钥加密
fromBase64(String base64String) String
Base64 解码
sha256String(String text) String
SHA-256 哈希值
signString(String text, String private) String
私钥签名
toBase64(String input) String
Base64 编码和解码
verifyString(String message, String signature, String public) bool
公钥验签名