HbDialog class

Constructors

HbDialog()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

getter/setter pair

Static Methods

closeAllLoading() → dynamic
关闭loading
errorToast(String msg) → void
错误toast
notify({required String title, TextStyle? titleStyle, String? subtitle, TextStyle? subtitleStyle, Widget? leading, Color backgroundColor = Colors.white, Duration duration = const Duration(seconds: 4), void onTap()?}) → void
顶部下拉显示的通知
openDialog({String content = '--', String? confirmText, String? cancelText, String? titleText, String? icon}) Future<bool?>
提示框
setup({String? defaultDialogIcon, Widget? loadingWidget}) TransitionBuilder
showLoading({Widget? loadingWidget}) CancelFunc
loading
successToast(String msg) → void
成功toast
warnToast(String msg) → void
警告toast