HbFormController class

Constructors

HbFormController()

Properties

hashCode int
The hash code for this object.
no setterinherited
key GlobalKey<FormState>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Map<String, dynamic>
final

Methods

clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited