HbSelect class
- Inheritance
- Available extensions
Constructors
-
HbSelect({Key? key, String? name, bool show = true, GlobalKey<
State< ? inputKey, GlobalKey<StatefulWidget> >State< ? preKey, String? label, String? email, Widget? rightLabel, Widget? labelWeight, TextEditingController? controller, TextEditingController? preController, String? initialValue, bool autofocus = false, bool enabled = true, bool? readOnly, String? hintText, String? uploadTip, Widget? suffix, Widget? prefix, Widget? defaultImage, Widget? customWidget, int? maxLength, int? maxLines, HbValidatorType validatorType = HbValidatorType.require, HbValidatorFnType? validator, TextInputAction? textInputAction, TextInputType? keyboardType, ValueChanged<StatefulWidget> >String> ? onChanged, ValueChanged<int> ? onSelected, ValueChanged<String> ? onFieldSubmitted, GestureTapCallback? onTap, GestureTapCallback? onBlur, List<HbSelectItemModel> selectItems = const [], HbRadioController? radioController, List<TextInputFormatter> ? inputFormatters, bool showIcon = true, bool showDescription = true, Function? sendCode}) - HbSelect.fromData(HbFormData data, {Key? key})
Properties
- bottomCenter → Widget
-
Available on Widget, provided by the HbWidgetExtension extension
no setter - center → Widget
-
Available on Widget, provided by the HbWidgetExtension extension
no setter - data → HbFormData
-
final
- expanded → Widget
-
Available on Widget, provided by the HbWidgetExtension extension
no setter -
formValue
↔ Map<
String, dynamic> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- left → Widget
-
Available on Widget, provided by the HbWidgetExtension extension
no setter - right → Widget
-
Available on Widget, provided by the HbWidgetExtension extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topCenter → Widget
-
Available on Widget, provided by the HbWidgetExtension extension
no setter - topLeft → Widget
-
Available on Widget, provided by the HbWidgetExtension extension
no setter - topRight → Widget
-
Available on Widget, provided by the HbWidgetExtension extension
no setter - toSliver → Widget
-
Available on Widget, provided by the HbWidgetExtension extension
no setter
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< HbSelect> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onGestureTap(
GestureTapCallback? onTap) → MouseRegion -
Available on Widget, provided by the HbWidgetExtension extension
-
onInkTap(
GestureTapCallback? onTap, {BoxDecoration? decoration}) → Ink -
Available on Widget, provided by the HbWidgetExtension extension
-
p(
double distance) → Widget -
Available on Widget, provided by the HbWidgetExtension extension
-
pb(
double distance) → Widget -
Available on Widget, provided by the HbWidgetExtension extension
-
pl(
double distance) → Widget -
Available on Widget, provided by the HbWidgetExtension extension
-
pr(
double distance) → Widget -
Available on Widget, provided by the HbWidgetExtension extension
-
pt(
double distance) → Widget -
Available on Widget, provided by the HbWidgetExtension extension
-
px(
double distance) → Widget -
Available on Widget, provided by the HbWidgetExtension extension
-
py(
double distance) → Widget -
Available on Widget, provided by the HbWidgetExtension extension
-
setFormValue(
Map< String, dynamic> ? value) → void -
子类必须实现:返回对应表单控件
override
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
setDefaultSelect(
{List< HbSelectItemModel> ? list, required HbRadioController controller, String? value, bool isForce = true}) → void - 设置默认选中
-
showBottomSelector(
BuildContext context, {String? title, required List< HbSelectItemModel> items, bool showIcon = true, bool showDescription = true, required HbRadioController controller, ValueChanged<int> ? onSelected}) → dynamic - 弹出底部选择弹窗