HbStorage class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
get<T>(String key)
→ T?
-
Retrieve data from the local cache
取出缓存
-
init()
→ Future<void>
-
Initialize the shared preferences with a cache
-
remove(String key)
→ Future<void>
-
Clear data from the local cache
删除缓存
-
set<T>(String key, T value)
→ Future<void>
-
Save data to the local cache
设置本地缓存