HbFormData class
Constructors
-
HbFormData({String? name, bool show = true, GlobalKey<
State< ? inputKey, Widget? customWidget, GlobalKey<StatefulWidget> >State< ? preKey, String? label, Widget? labelWeight, Widget? rightLabel, String? initialValue, TextEditingController? controller, bool autofocus = false, bool enabled = true, bool? readOnly, bool showIcon = true, bool showDescription = true, String? hintText, String? uploadTip, HbValidatorType validatorType = HbValidatorType.require, TextEditingController? preController, String? email, Widget? suffix, Widget? prefix, HbValidatorFnType? validator, TextInputAction? textInputAction, TextInputType? keyboardType, ValueChanged<StatefulWidget> >String> ? onChanged, ValueChanged<int> ? onSelected, ValueChanged<String> ? onFieldSubmitted, HbRadioController? radioController, GestureTapCallback? onTap, GestureTapCallback? onBlur, List<HbSelectItemModel> selectItems = const [], List<TextInputFormatter> ? inputFormatters, Widget? defaultImage, int? maxLines, int? maxLength, Function? sendCode, String? labelTextInBox})
Properties
- autofocus → bool
-
final
- controller → TextEditingController?
-
final
- customWidget → Widget?
-
final
- defaultImage → Widget?
-
final
- email → String?
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String?
-
final
- initialValue → String?
-
final
-
inputFormatters
→ List<
TextInputFormatter> ? -
final
-
inputKey
→ GlobalKey<
State< ?StatefulWidget> > -
final
- keyboardType → TextInputType?
-
final
- label → String?
-
final
- labelTextInBox → String?
-
final
- labelWeight → Widget?
-
final
- maxLength → int?
-
final
- maxLines → int?
-
final
- name → String?
-
final
- onBlur → GestureTapCallback?
-
final
-
onChanged
→ ValueChanged<
String> ? -
final
-
onFieldSubmitted
→ ValueChanged<
String> ? -
final
-
onSelected
→ ValueChanged<
int> ? -
final
- onTap → GestureTapCallback?
-
final
- preController → TextEditingController?
-
final
- prefix → Widget?
-
final
-
preKey
→ GlobalKey<
State< ?StatefulWidget> > -
final
- radioController → HbRadioController?
-
final
- readOnly → bool?
-
final
- rightLabel → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectItems
→ List<
HbSelectItemModel> -
final
- sendCode → Function?
-
final
- show → bool
-
final
- showDescription → bool
-
final
- showIcon → bool
-
final
- suffix → Widget?
-
final
- textInputAction → TextInputAction?
-
final
- uploadTip → String?
-
final
- validator → HbValidatorFnType?
-
final
- validatorType → HbValidatorType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited